@@ -166,9 +166,12 @@ class PandasDataFrameRoundtrip(DiskTestCase):
         ctx = tiledb.Ctx()
         tiledb.from_dataframe(uri, df, sparse=False, ctx=ctx)
 
-        # TODO tiledb.read_dataframe
         df_readback = tiledb.open_dataframe(uri)
+        tm.assert_frame_equal(df, df_readback)
 
+        uri = self.path("dataframe_basic_rt1_unlimited")
+        tiledb.from_dataframe(uri, df, full_domain=True, sparse=False, ctx=ctx)
+        df_readback = tiledb.open_dataframe(uri)
         tm.assert_frame_equal(df, df_readback)
 
     def test_dataframe_basic2(self):
@@ -294,6 +297,9 @@ class PandasDataFrameRoundtrip(DiskTestCase):
             df_idx_res = A.df[slice(*ned_time), :]
             tm.assert_frame_equal(df_idx_res, df)
 
+            # test .df[] indexing with query
+            df_idx_res = A.query(attrs=['int_vals']).df[slice(*ned_time), :]
+            tm.assert_frame_equal(df_idx_res, df)
 
     def test_csv_dense(self):
         col_size = 10
@@ -312,7 +318,14 @@ class PandasDataFrameRoundtrip(DiskTestCase):
         df.to_csv(tmp_csv)
 
         tmp_array = os.path.join(tmp_dir, "array")
-        tiledb.from_csv(tmp_array, tmp_csv, index_col=['index'],
+        tiledb.from_csv(tmp_array,
+                        tmp_csv,
+                        index_col=['index'],
+                        dtype={'index': np.uint64},
+                        sparse=False)
+
+        tmp_array2 = os.path.join(tmp_dir, "array2")
+        tiledb.from_csv(tmp_array2, tmp_csv,
                         sparse=False)
 
     def test_csv_col_to_sparse_dims(self):
@@ -480,6 +493,9 @@ class PandasDataFrameRoundtrip(DiskTestCase):
                         chunksize=25)
 
         with tiledb.open(tmp_array_dense) as A:
+            # with sparse=False and no index column, we expect to have unlimited domain
+            self.assertEqual(A.schema.domain.dim(0).domain[1], 18446744073709541615)
+
             # chunked writes go to unlimited domain, so we must only read nonempty
             ned = A.nonempty_domain()[0]
             # TODO should support numpy scalar here
@@ -492,6 +508,17 @@ class PandasDataFrameRoundtrip(DiskTestCase):
             df_idx_res = A.df[int(ned[0]):int(ned[1])]
             tm.assert_frame_equal(df_idx_res, df)
 
+            # test .df[] indexing with query
+            df_idx_res = A.query(attrs=['time']).df[int(ned[0]):int(ned[1])]
+            tm.assert_frame_equal(df_idx_res, df[['time']])
+
+            df_idx_res = A.query(attrs=['double_range']).df[int(ned[0]):int(ned[1])]
+            tm.assert_frame_equal(df_idx_res, df[['double_range']])
+
+            # disable coordinate dimension/index
+            df_idx_res = A.query(coords=False).df[int(ned[0]):int(ned[1])]
+            tm.assert_frame_equal(df_idx_res, df.reset_index(drop=True))
+
     def test_csv_fillna(self):
         col_size = 10
         data = np.random.rand(10) * 100 # make some integers for the 2nd test
@@ -512,7 +539,7 @@ class PandasDataFrameRoundtrip(DiskTestCase):
             df['v'][4] = 0
 
             with tiledb.open(path) as A:
-                df_bk = A.df[:] #pd.DataFrame.from_dict(res)
+                df_bk = A.df[:]
                 tm.assert_frame_equal(df_bk, df)
 
         check_array(tmp_array, copy.deepcopy(df))
